#!/usr/local/bin/perl -s
#
# merge_files
#
# Perl subroutine to merge new information into an existing file used as input to
# the SOHOPARR program.  General format of these files is:
# keyword yy/mm/dd hh:mm:ss yy/mm/dd hh:mm:ss xxhxxmxxs
# This program will replace data in the cumulative file with data read from a new
# updated file and store the resulting merged data in an output file.
#
# Calling sequence:
#   $status = &merge_files (current_file, new_file, out_file)
# 
# Data for the times range covered by new_file will be replaced in current_file.
#
# Written: Kim 10/30/96
#
#------------------------------------------------------------------------

sub merge_files 
{

@INC = (@INC, "/u/ecs/util");
require "ymdtime_to_sec.pl";
require "ext_time.pl";

# get input arguments - current file name and new file name.
local($cur_file, $new_file, $out_file) = @_;

local ($sav_file, @cur_lines, @new_lines, @word, @earlier, @later,
$secstart, $secend);

# Copy the current file into a save file just to have a backup.
$sav_file = $cur_file.".sav";  system "cp $cur_file $sav_file";

open (OUT_FILE, ">$out_file") || die "Can't open file $out_file.  $! \n";

# open and read current file
open (CUR_FILE, "$cur_file") || die "Can't open file $cur_file.  $! \n";
@cur_lines = <CUR_FILE>;

# open and read new file
open (NEW_FILE, "$new_file") || die "Can't open file $new_file.  $! \n";
@new_lines = <NEW_FILE>;

# get start and end time of new file in seconds (first get rid of blanks at the
# beginning of first and last line)
for (0,$#new_lines) { ($new_lines[$_] = $new_lines[$_]) =~ s/^ +//g; }
@words = split (/[ \t\n]+/, $new_lines[0]);
$secstart = &ymdtime_to_sec ($words[1],$words[2]);
@words = split (/[ \t\n]+/, $new_lines[$#new_lines]);
$secend = &ymdtime_to_sec ($words[1],$words[2]);

# find lines from current file whose time is before the start of the new file
@earlier = grep ( (&ext_time($_, 1, 2) < $secstart), @cur_lines);

# find lines from current file whose time is after the end of the new file
@later = grep ( (&ext_time($_, 1, 2) > $secend), @cur_lines);

# write earlier lines from current file, lines from new file, and then later 
# lines from current file into output file.
print OUT_FILE (@earlier, @new_lines, @later);
close OUT_FILE;

}
1;
