/* $Id$ */
/***************************************************************************
 FILENAME: cmdhist.c
 FILE CONTAINS:
	   main
           get_local_env_vars
           process_cmd_line

 PURPOSE:  Processes a CMS Command History Report file offline.

 NOTE:     Under normal operations a CMS Command History file is processed
	   by the manage_file_alerts process (CMS sends a file alert msg,
           EOF retrieves the file, EOF reformats the file and merges it with
           other cmd hist files for the same operational day, EOF updates the
           Time Correlation File with any clock corrections in the cmd hist
           file).  
           However, there may be circumstances where this is not possible.
 ***************************************************************************/
/* $Log$ */

#include <stdio.h>
#include <stdlib.h>
#include <signal.h>
#include <errno.h>

#include "/ecsr6b4_tst/source/include/mission.h"    /* mission-specific declarations */

/* global data */
char *cmd_hist_filename;
char *cmd_hist_dir;         /* ENV VAR Command History directory on ECS */
char *temp_files_dir;       /* ENV VAR Temp Files      directory on ECS */

/* function prototypes */
int process_cmd_line(int argc, char **argv);
int get_local_env_vars(void);


void main (int argc, char **argv)
{

   if (process_cmd_line(argc, argv))
   {
      printf("\nCMDHIST command line error");
      printf("\nCMDHIST Program Exiting...\n");
      exit(ERR);
   }

   /* get environment variables */
   get_local_env_vars();

   /* process the CMS command history report offline */
   if (offline_cmd_hist_rpt(cmd_hist_filename) != OK)
   {
      printf("\nCMDHIST Error Processing File %s\n",cmd_hist_filename);
      printf("\nCMDHIST Program Exiting...\n");
      exit(ERR);
   }

}  /* end main */


int process_cmd_line(int argc, char **argv)
{
   if (argc != 2)
   {
      printf("\nCMDHIST usage: cmdhist </full_path/filename>");
      printf("\nCMDHIST Program Exiting...\n");
      exit(ERR);
   }
   cmd_hist_filename = argv[1]; 

   if (strchr(cmd_hist_filename,'/') == NULL)
   {
      printf("\nCMDHIST usage: cmdhist </full_path/filename>");
      printf("\nCMDHIST Program Exiting...\n");
      exit(ERR);
   }

   return(OK);
}  /* end process_cmd_line */


int get_local_env_vars(void)
{
   cmd_hist_dir = getenv("CMD_HIST_DIR");
   if (cmd_hist_dir == NULL)
   {  /* env var not defined */
      printf("\nCMDHIST: Environment Variable CMD_HIST_DIR Not Defined\n");
      printf("\nCMDHIST Program Exiting...\n");
      exit(ERR);
   }

   if (*cmd_hist_dir == NULL)
   {  /* env var not set */
      printf("\nCMDHIST: Environment Variable CMD_HIST_DIR Not Defined\n");
      printf("\nCMDHIST Program Exiting...\n");
      exit(ERR);
   }

   temp_files_dir = getenv("TEMP_FILES_DIR");
   if (temp_files_dir == NULL)
   {  /* env var not defined */
      printf("\nCMDHIST: Environment Variable TEMP_FILES_DIR Not Defined\n");
      printf("\nCMDHIST Program Exiting...\n");
      exit(ERR);
   }

   if (*temp_files_dir == NULL)
   {  /* env var not set */
      printf("\nCMDHIST: Environment Variable TEMP_FILES_DIR Not Defined\n");
      printf("\nCMDHIST Program Exiting...\n");
      exit(ERR);
   }

   return(OK);
}  /* end get_local_env_vars */


/*********************************************************************
 FUNCTION NAME:         offline_cmd_hist_rpt
 INPUT  PARAMETERS:     char *filename
 OUTPUT PARAMETERS:     None
 RETURN VALUE:          int rc (OK, ERR)
 REFERENCED DATA FILES: CMS command history report file
 PURPOSE:       Read CMS command history report file to find time
                corrections.  Write time corrections to time correlation
                log.  Rename time correlation log
                with current date/time (or last time correction date/time?).
 NOTE:  filename is <ecs directory>/<filename>
 *********************************************************************/
int offline_cmd_hist_rpt(char *filename)
{
   int rc = OK;
   char filedate[MAXBUFFER];
   char scihist2[MAXBUFFER];
   char scibck2[MAXBUFFER];
   char final_cmd_hist[MAXBUFFER];
   char errmsg[MAXBUFFER];

   /* get time corrections from the Command History Report for the
      Time Correlation Log (TCL) File */
   update_TCF_file(filename);

   /* merge this POCC cmd hist file with others for this op day */
   if (offline_split_cmdhist(filename, &filedate, &scihist2, &scibck2) == OK)
   {
      if (offline_merge_cmdhist(filedate, scihist2, scibck2, &final_cmd_hist) == ERR)
      {
         printf("ERROR Merging %s and %s Into %s\n",
                 scihist2, scibck2, final_cmd_hist);
      }
   }
   else
   {
      printf("ERROR Cannot Process Cmd Hist File %s\n", filename);
   }
   return(rc);
}  /* end offline_cmd_hist_rpt */
